@@ -1,6 +1,6 @@
-//$Id: bitmap-win.cc,v 1.22 2006/10/06 22:35:39 cactus Exp $ -*- c++ -*-
+//$Id: bitmap-win.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -183,14 +183,14 @@ void GUI::BitmapWindow::load_image_cb ()
 void GUI::BitmapWindow::export_image_cb ()
 {
     char *title = g_strdup_printf (_("Exporting %s"), res->id ().c_str ());
-    FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_SAVE);
+    FileChooserDialog file_chooser (window, title, Gtk::FILE_CHOOSER_ACTION_SAVE, "png");
     g_free (title);
     
     Gtk::FileFilter filter;
     filter.set_name (_("PNG files"));
     filter.add_mime_type ("image/png");
     file_chooser.add_filter (filter);
-
-    if (UI::confirm_save (file_chooser))
+    
+    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
 	res->save_file_png (file_chooser.get_uri ());
 }
