@@ -1,6 +1,6 @@
-//$Id: bitmapfamily-res-ops.cc,v 1.7 2006/10/06 22:35:39 cactus Exp $ -*- c++ -*-
+//$Id: bitmapfamily-res-ops.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -36,7 +36,7 @@ namespace {
     
     Glib::ustring get_change_label (Resources::Bitmap::BitmapType type)
     {
-        char *msgid = 0;
+        const char *msgid = 0;
 
         switch (type)
         {
@@ -67,7 +67,7 @@ namespace {
 
     Glib::ustring get_remove_label (Resources::Bitmap::BitmapType type)
     {
-        char *msgid = 0;
+        const char *msgid = 0;
 
         switch (type)
         {
