@@ -1,6 +1,6 @@
-//$Id: cellrenderer-icontext.cc,v 1.8 2006/10/06 22:35:40 cactus Exp $ -*- c++ -*-
+//$Id: cellrenderer-icontext.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -78,7 +78,7 @@ void CellRendererIconText::render_vfunc (const Glib::RefPtr<Gdk::Drawable> &wind
                                          Gtk::CellRendererState             flags)
 {
     // This ugly cast is necessary to work around a bug in GTKmm 2.4
-    const Glib::RefPtr<Gdk::Window> &window_win = reinterpret_cast<const Glib::RefPtr<Gdk::Window>&> (window);
+    Glib::RefPtr<Gdk::Window> window_win = Glib::RefPtr<Gdk::Window>::cast_dynamic (window);
     
     int pix_x, pix_y, pix_w, pix_h;    
     cell_pixbuf.get_size (widget, cell_area, pix_x, pix_y, pix_w, pix_h);
