@@ -1,6 +1,6 @@
-//$Id: cellrenderer-indent.cc,v 1.6 2006/10/06 22:35:40 cactus Exp $ -*- c++ -*-
+//$Id: cellrenderer-indent.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -70,7 +70,8 @@ void CellRendererIndentBase::render_vfunc (const Glib::RefPtr<Gdk::Drawable> &wi
                                            const Gdk::Rectangle              &expose_area,
                                            Gtk::CellRendererState             flags)
 {
-    const Glib::RefPtr<Gdk::Window> &window_win = reinterpret_cast<const Glib::RefPtr<Gdk::Window>&> (window);
+    // This ugly cast is necessary to work around a bug in GTKmm 2.4
+    Glib::RefPtr<Gdk::Window> window_win = Glib::RefPtr<Gdk::Window>::cast_dynamic (window);
 
     int real_x, real_y, real_w, real_h;    
     get_real_cell ()->get_size (widget, cell_area, real_x, real_y, real_w, real_h);
