@@ -1,6 +1,6 @@
-//$Id: dialog-win-helpers.cc,v 1.10 2006/10/06 22:35:40 cactus Exp $ -*- c++ -*-
+//$Id: dialog-win-helpers.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -56,9 +56,8 @@ void ButtonList::button_default_cb ()
 
     unsigned int index = path[0];
 
-    static ResourceOps::PropChangeOpFactory<unsigned int> op_factory (
-	_("Change default button of %s"), res, res->default_button, true);
-    
+    ResourceOps::PropChangeOpFactory<unsigned int> op_factory (
+        _("Change default button of %s"), res, res->default_button, true);    
     op_factory.push_change (index);
 }
 
