@@ -1,6 +1,6 @@
-//$Id: menubar-canvas.cc,v 1.3 2006/10/06 22:35:42 cactus Exp $ -*- c++ -*-
+//$Id: menubar-canvas.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -102,15 +102,15 @@ void MenubarCanvasItem::update ()
     const Resources::Menu::MenuTree &submenus = res->get_submenus ();
     int x = 9;
     submenu_items.reserve (submenus.size ());
-    for (unsigned int i = 0; i != submenus.size (); ++i)
+    int submenu_idx = 0;
+    for (Resources::Menu::MenuTree::const_iterator i = submenus.begin (); i != submenus.end (); ++i, ++submenu_idx)
     {
-        SubmenuCanvasItem *submenu_item = new SubmenuCanvasItem (
-            *item_group, submenus[i], res->get_manager ()->get_target (), x);
+        SubmenuCanvasItem *submenu_item = new SubmenuCanvasItem (*item_group, *i, res->get_manager ()->get_target (), x);
         submenu_item->clicked.connect (
             sigc::bind (sigc::mem_fun (*this, &MenubarCanvasItem::submenu_clicked_cb), submenu_item));
         
         submenu_items.push_back (submenu_item);
-        if (i == int(rolled_down_submenu_idx))
+        if (submenu_idx == rolled_down_submenu_idx)
             submenu_item->roll_down ();
     }
 }
