@@ -1,6 +1,6 @@
-//$Id: gnome-i18n-cnp.cc,v 1.7 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
+//$Id: gnome-i18n-cnp.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  *
  * The contents of this file is either copied verbatim or ported to
  * C++, from libgnome-2.0, which in turn takes most of it from GNU
@@ -37,7 +37,7 @@ namespace
     GHashTable *alias_table = NULL;
     
     // read an alias file for the locales
-    static void read_aliases (char *file)
+    static void read_aliases (const char *file)
     {
 	FILE *fp;
 	char buf[256];
