@@ -1,6 +1,6 @@
-//$Id: guikachu-io.h,v 1.2 2006/10/06 22:35:44 cactus Exp $ -*- c++ -*-
+//$Id: guikachu-io.h 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -36,7 +36,7 @@ namespace Guikachu
     {
         void init ();
         
-	Glib::ustring create_canonical_uri (const Glib::ustring &filename);
+	Glib::ustring create_canonical_uri (const Glib::ustring &filename, const Glib::ustring &default_ext = "");
         Glib::ustring get_mime_type (const Glib::ustring &uri) throw (Glib::Exception);
         
 	void load_uri (const Glib::ustring &uri, unsigned char *&data, filesize_t &len) throw (Glib::Exception);
