@@ -1,6 +1,6 @@
-//$Id: mainwin-io.cc,v 1.48 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
+//$Id: mainwin-io.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -168,7 +168,7 @@ void GUI::MainWin::save_cb ()
 
 void GUI::MainWin::save_as_cb ()
 {
-    FileChooserDialog file_chooser (*this, _("Save Guikachu file"), Gtk::FILE_CHOOSER_ACTION_SAVE);
+    FileChooserDialog file_chooser (*this, _("Save Guikachu file"), Gtk::FILE_CHOOSER_ACTION_SAVE, "guikachu");
 
     Gtk::FileFilter filter_guikachu;
     filter_guikachu.set_name (_("Guikachu documents"));
@@ -178,13 +178,13 @@ void GUI::MainWin::save_as_cb ()
     filter_guikachu.add_pattern ("*.guikachu");
 #endif
     file_chooser.add_filter (filter_guikachu);
-
+    
     Gtk::FileFilter filter_all;
     filter_all.set_name (_("All files"));
     filter_all.add_pattern ("*");
     file_chooser.add_filter (filter_all);
-    
-    if (UI::confirm_save (file_chooser))
+
+    if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
         Guikachu::Main::instance ()->save_doc (file_chooser.get_uri ());
 }
     
@@ -210,6 +210,7 @@ void GUI::MainWin::load_cb ()
 #endif
     file_chooser.add_filter (filter_rcp);
 
+    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);
     if (file_chooser.run () == Gtk::RESPONSE_ACCEPT)
         open (file_chooser.get_uri ());
 }
@@ -232,6 +233,7 @@ void GUI::MainWin::export_cb ()
     filter_all.add_pattern ("*");
     file_chooser.add_filter (filter_all);
     
+    file_chooser.set_default_response (Gtk::RESPONSE_ACCEPT);    
     if (file_chooser.run () != Gtk::RESPONSE_ACCEPT)
         return;
     
