@@ -1,6 +1,6 @@
-//$Id: mainwin.cc,v 1.70 2006/10/06 22:35:41 cactus Exp $ -*- c++ -*-
+//$Id: mainwin.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -188,8 +188,7 @@ void GUI::MainWin::set_view_mode (bool grouped)
 
     const char *action_name = grouped ? "resources_tree" : "resources_flat";
     Glib::RefPtr<Gtk::Action> grouped_action = main_group->get_action (action_name);
-    Glib::RefPtr<Gtk::RadioAction> &grouped_radio_action = 
-        reinterpret_cast<Glib::RefPtr<Gtk::RadioAction>& > (grouped_action);
+    Glib::RefPtr<Gtk::RadioAction> grouped_radio_action = Glib::RefPtr<Gtk::RadioAction>::cast_dynamic (grouped_action);
     grouped_radio_action->set_active (true);
     
     resource_tree.set_grouped (grouped);
@@ -211,18 +210,16 @@ void GUI::MainWin::update_title ()
 
 void GUI::MainWin::toggle_toolbar_cb ()
 {
-    const Glib::RefPtr<Gtk::Action> &action = main_group->get_action ("toggle_toolbar");
-    const Glib::RefPtr<Gtk::ToggleAction> &toggleaction =
-        reinterpret_cast<const Glib::RefPtr<Gtk::ToggleAction>& > (action);
+    Glib::RefPtr<Gtk::Action> action = main_group->get_action ("toggle_toolbar");
+    Glib::RefPtr<Gtk::ToggleAction> toggleaction = Glib::RefPtr<Gtk::ToggleAction>::cast_dynamic (action);
     
     set_show_toolbar (toggleaction->get_active ());
 }
 
 void GUI::MainWin::viewmode_cb ()
 {
-    const Glib::RefPtr<Gtk::Action> &grouped_action = main_group->get_action ("resources_tree");
-    const Glib::RefPtr<Gtk::RadioAction> &grouped_radio_action = 
-        reinterpret_cast<const Glib::RefPtr<Gtk::RadioAction>& > (grouped_action);
+    Glib::RefPtr<Gtk::Action> grouped_action = main_group->get_action ("resources_tree");
+    Glib::RefPtr<Gtk::RadioAction> grouped_radio_action = Glib::RefPtr<Gtk::RadioAction>::cast_dynamic (grouped_action);
     
     set_view_mode (grouped_radio_action->get_active ());
 }
@@ -230,7 +227,7 @@ void GUI::MainWin::viewmode_cb ()
 void GUI::MainWin::set_show_toolbar (bool show)
 {
     Glib::RefPtr<Gtk::Action> action = main_group->get_action ("toggle_toolbar");
-    Glib::RefPtr<Gtk::ToggleAction> &toggleaction = reinterpret_cast<Glib::RefPtr<Gtk::ToggleAction>&> (action);
+    Glib::RefPtr<Gtk::ToggleAction> toggleaction = Glib::RefPtr<Gtk::ToggleAction>::cast_dynamic (action);
     toggleaction->set_active (show);
     
     if (show)
