@@ -1,6 +1,6 @@
-//$Id: filechooserdialog.h,v 1.2 2006/10/06 22:35:46 cactus Exp $ -*- c++ -*-
+//$Id: filechooserdialog.h 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -27,12 +27,17 @@ namespace Guikachu
     {
         class FileChooserDialog: public Gtk::FileChooserDialog
         {
+            Glib::ustring default_ext;
+            
         public:
             FileChooserDialog (Gtk::Window            &parent_window,
                                const Glib::ustring    &title,
-                               Gtk::FileChooserAction  action);
+                               Gtk::FileChooserAction  action,
+                               const Glib::ustring    &default_ext = Glib::ustring ());
 
             Glib::ustring get_uri () const;
+
+            int run ();
         };
     }
 }
