@@ -1,6 +1,6 @@
-//$Id: string-list.cc,v 1.22 2006/10/06 22:35:47 cactus Exp $ -*- c++ -*-
+//$Id: string-list.cc 1432 2007-08-04 20:19:42Z cactus $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001-2006 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2007 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -21,6 +21,7 @@
 #include <glib/gi18n.h>
 
 #include "ui.h"
+#include "cellrenderer-livetext.h"
 
 #include <gtkmm/scrolledwindow.h>
 #include <gtkmm/stock.h>
@@ -66,7 +67,7 @@ StringList::StringList (property_t   &property_,
     
     property.changed.connect (sigc::mem_fun (*this, &StringList::update));
 
-    // We call setup() from and idle handler because it needs to call
+    // We call setup() from an idle handler because it needs to call
     // virtual member functions
     Glib::signal_idle ().connect (sigc::bind_return (
 	sigc::mem_fun (*this, &StringList::setup), false));
@@ -96,9 +97,36 @@ void StringList::create_columns (Gtk::TreeModel::ColumnRecord &columns)
     columns.add (col_text);
 }
 
+namespace
+{
+    // Copied and modified from Gtk::TreeView_Private::_auto_store_on_cellrenderer_text_edited_string
+    void store_text(const Glib::ustring& path_string, const Glib::ustring& new_text, int model_column, const Glib::RefPtr<Gtk::TreeModel>& model)
+    {
+        Gtk::TreePath path (path_string);        
+        Gtk::TreeModel::iterator iter = model->get_iter(path);
+        if (iter)
+            iter->set_value(model_column, new_text);
+    }
+
+    // Copied and modified from Gtk::TreeView_Private::_connect_auto_store_editable_signal_handler
+    void setup_editable_cell (Gtk::TreeView                             &treeview,
+                              Guikachu::GUI::CellRendererLiveText       &cell,
+                              const Gtk::TreeModelColumn<Glib::ustring> &model_column)
+    {
+        cell.property_editable () = true;        
+        cell.signal_edited().connect (sigc::bind (sigc::ptr_fun (&store_text), model_column.index (), treeview.get_model()));
+    }
+}
+
 void StringList::create_view_columns (int &col_text_num)
 {
-    treeview.append_column_editable ("", col_text);
+    CellRendererLiveText *cell = new CellRendererLiveText;
+    Gtk::TreeViewColumn *view_col = new Gtk::TreeViewColumn ("", *manage (cell));
+    view_col->set_renderer (*cell, col_text);
+
+    setup_editable_cell (treeview, *cell, col_text);
+    
+    treeview.append_column (*manage (view_col));
 
     col_text_num = 0;
 }
